CHANGES
========

0.4 (19-06-2015)
----------------

- New features keys may be "str" typed and extension method "prepend" is "+" on python

0.3 (16-06-2015)
----------------

- New features new type of values "str" and extension method "append" is "+" on python

0.2 (15-06-2015)
----------------

- New features "add", "replace", "append", "prepend"

0.1 (10-06-2015)
----------------

- Initial release
